@@ -11,6 +11,22 @@ from pygitpub.static import VERSION_STR
 from pygitpub.utils import delete
 
 
+@register_endpoint(
+    description="List all repos",
+    configs=[
+        ConfigGithub,
+    ],
+)
+def repos_list_verbose() -> None:
+    g = github.Github(login_or_token=ConfigGithub.token)
+    for repo in g.get_user(ConfigGithub.username).get_repos():
+        if repo.description is None:
+            description = "NONE"
+        else:
+            description = repo.description
+        print(",".join([repo.name, description, str(repo.fork)]))
+
+
 @register_endpoint(
     description="List all repos",
     configs=[
@@ -23,6 +39,19 @@ def repos_list() -> None:
         print(repo.name)
 
 
+@register_endpoint(
+    description="List all private repos",
+    configs=[
+        ConfigGithub,
+    ],
+)
+def repos_list_private() -> None:
+    g = github.Github(login_or_token=ConfigGithub.token)
+    for repo in g.get_user().get_repos(type="private"):
+        if not repo.fork:
+            print(f"{repo.name}")
+
+
 @register_endpoint(
     description="Cleanup old failing or un-needed runs",
     configs=[
